@@ -313,6 +313,8 @@ thumb_app_setup_play (ThumbApp *app)
 {
 	GstElement *play;
 	GstElement *audio_sink, *video_sink;
+	GstRegistry *registry;
+	GstPluginFeature *feature;
 
 	play = gst_element_factory_make ("playbin", "play");
 	audio_sink = gst_element_factory_make ("fakesink", "audio-fake-sink");
@@ -326,6 +328,17 @@ thumb_app_setup_play (ThumbApp *app)
 		      NULL);
 
 	app->play = play;
+
+	/* Disable the vaapi plugin as it will not work with the
+	 * fakesink we use:
+	 * See: https://bugzilla.gnome.org/show_bug.cgi?id=700186 */
+	registry = gst_registry_get ();
+	feature = gst_registry_find_feature (registry,
+					     "vaapidecode",
+					     GST_TYPE_ELEMENT_FACTORY);
+	if (!feature)
+		return;
+	gst_registry_remove_feature (registry, feature);
 }
 
 static void
